<?php
/**
 * MiniMVC
 *
 * Convention-based micro-framework for PHP
 *
 * @package		miniMVC
 * @author 		Timothy J. Warren
 * @copyright	Copyright (c) 2011 - 2012
 * @link 		https://github.com/aviat4ion/miniMVC
 * @license 	http://philsturgeon.co.uk/code/dbad-license 
 */
 
// --------------------------------------------------------------------------

namespace miniMVC;

/** 
 * Parent trait of base class, contains much of the magic
 *
 * @package miniMVC
 * @subpackage System
 */
trait JSObject {

	use Generic;

	/**
 	 * Constructor for creating the objects
 	 *
 	 * @param array $members
 	 * @return void
 	 */
 	public function __construct($members = [])
 	{
 		// Add the passed parameters to the object
 		foreach($members as $name => &$value)
 		{
 			$this->$name = $value;
 		}
 	}
 	
 	// --------------------------------------------------------------------------
 	
 	/** 
	 * PHP magic method to facilitate dynamic methods
	 *
	 * @param string $name
	 * @param array $params
	 */
	public function __call($name, $params = [])
	{
		if (is_callable($this->$name))
		{	
			//Call the dynamic function
			return call_user_func_array($this->$name, $params);
		}
	}
}

// End of JSObject.php